@@ -214,7 +214,7 @@ def cli(command,
     invoke_class = NxPyDocs(command,
                             filetype,
                         )
-    invoke_class.abortion_policies()
+    invoke_class.nxpydocs()
 
 if __name__ == "__main__":
     cli()
